# DigiCloud Command Line Interface 

## Install
To install the client run the following command:

```bash
python setup.py install
```

## bash auto completion
After install you can use ``digicloud`` command ``bashcompletion`` to
to generate auto completion bash script.

```bash
digicloud complete > /etc/bash_completion.d/digicloud
```

## Development

Install preferably inside your choice of virtual environments like
poetry or pipenv.

Use edit mode:

```bash
python -m pip install -e .
```
